#' ---
#' title: "Assignment"
#' output: pdf_document
#' ---
#' 
#' # Question 1
#' ## Part a
#' 
#' Let x1, x2....xn be the sample from normal distribution with mean $\mu$, then $T = \frac{\bar{x} - \mu}{\frac{s}{\sqrt{n}}}$ follows student t distribution with degree of freedom equal to n-1. We can use this expression to obtain a confidence interval for mean $\mu$. To obtain a two sided symmetric 99% confidence interval, we can leave a region of area 0.5% on each side i.e., 99% confidence interval in this case would be 
#' $$(\bar{x} - t_{n-1, 0.995}*\frac{x}{\sqrt{n}}, \bar{x}  - t_{n-1, 0.005}*\frac{x}{\sqrt{n}})$$
#' where $t_{n-1, p}$ denote the p percentile of student t distribution with df = n-1. In case of student t distribution $t_{n-1, 0.005} = t_{n-1, 0.995}$ thus the interval could be simplified as 
#' $$(\bar{x} - t_{n-1, 0.995}*\frac{x}{\sqrt{n}}, \bar{x}  + t_{n-1, 0.995}*\frac{x}{\sqrt{n}})$$
#' Substituting the values
## ----1a------------------------------------------------------------------
x = c(51, 44, 51, 43, 32, 38, 48, 45, 27, 34, 29, 26, 28, 23)
x_bar = mean(x)
x_sd = sd(x)

n = length(x)
q_cutoff = qt(0.995, n-1)

lower_bound_ci = x_bar - q_cutoff * (x_sd/sqrt(n))
upper_bound_ci = x_bar + q_cutoff * (x_sd/sqrt(n))

print(c(lower_bound_ci, upper_bound_ci))


#' 
#' We get confidence interval as (29.14898 44.99388)
#' 
#' ## Part b
#' It is claimed that the mean number of death is less than 72.6 To test the claim, we set the hypothesis in the following way
#' 
#' ##### H0 : $\mu$ >= 72.6
#' ##### H1 : $\mu$ < 72.6
#' 
#' Since the variance is unknown, we use the one sided t test at 0.01 significance level
#' 
## ----1b------------------------------------------------------------------
res = t.test(x, alternative = "l", mu = 72.6)
print(res)

#' 
#' Since p value = 2.494e-09 is less than 0.01, we reject H0 meaning that we have sufficient evidence to accept that the mean number of death is less than 72.6
#' 
#' 
#' # Question 2 
#' 
#' ## Part a
#' 
#' We can carry out the test of equality of means of two different normal distribution. The first population is the group of people who are non smokers exposed to environmental tobacco smoke (ETS) while the other group consists of smokers who are not exposed to it (NOETS). The hypothesis to test the claim can be set up in the following way
#' 
#' #### H0 : $\mu_{ETS} <= \mu_{NOETS}$
#' #### H1 : $\mu_{ETS} > \mu_{NOETS}$
#' 
#' This test is a one sided test
#' 
## ----2-------------------------------------------------------------------
df <- read.csv("~/Downloads/1650629459559_Dataset14_-_Passive_and_Active_Smoke.csv")
ETS = df$ETS
NOETS =df$NOETS

t.test(ETS, NOETS, alternative = "g", conf.level = 0.95)

#' Since p value < 0.05, hence there is sufficient evidence to reject the null hypothesis i.e., it can be concluded that the cotinine level for people in ETS group is higher than the NOETS group
#' 
#' ## Part b.
#' 
#' It can also be seen from the above result that the 95% confidence interval for $\mu_{ETS} - \mu_{NOETS}$ is $(4.12, \infty)$ which is obtained by inverting the relevant test statistics
#' 
#' # Question 3
#' 
#' We will use the Fischer exact test to test the claim. It is claimed that the survival rate for the VSD diagnosis is higher than that of the others category. To do this, we compare the odds of survival of VSD diagnosis with the others.
#' 
#' #### Odds of survival for VSD = 18/0 = $\infty$
#' #### Odds of survival for Other = 5/2 
#' 
#' Odds ratio  = Odd for survival for VSD / Odds of survival for Other
#' 
#' The test is setup in the following way
#' 
#' #### H0 : Odds ratio <= 1 
#' #### H1: Odds Ratio > 1
#' 
## ----3-------------------------------------------------------------------

# prop.test(c(18, 5), c(18, 7), alternative = "g", correct = FALSE)
fisher.test(matrix(c(18, 0, 5, 7), ncol=2), alternative = "g")


#' Since p value is less than any reasonable significance level, hence we reject the null hypothesis i.e., there is sufficient evidence to clain that the survival rate is higher for VSD diagnosis
#' 
#' # Question 4
#' 
#' ## Part a
## ----4a------------------------------------------------------------------
foot_length = read.csv("~/Downloads/1650629459139_footlength.csv")
set.seed(100)
sample_footlength = sample(foot_length$fl, 20)
t.test(sample_footlength, alternative = "two.sided", mu = 25.5)

#' Since p value = 0.4703 is greater that 0.05, hence null cannot be rejected, thus avergae foot length = 25.5cm
#' 
#' ## Part b
#' 
## ----4b------------------------------------------------------------------
set.seed(1000)
sample_footlength = sample(foot_length$fl, 20)
t.test(sample_footlength, alternative = "two.sided", mu = 25.5)

#' 
#' Since p value = 0.008 < 0.05, thus null hypothesis is rejected.Thus average foot length is not equal to 25.5. This is different from what we obtained in part a. It could be because of type II error. 
#' 
#' P(Type II Error) = P(Accepting the null | Null is False) = 1 - Power of the test
#' 
#' In the specific case of this problem, we compute the power of the test in the following code 
#' 
## ------------------------------------------------------------------------
sd_footlen = (length(foot_length$fl) - 1)*sd(foot_length$fl)/length(foot_length$fl)
power.t.test(n = 20, delta = mean(foot_length$fl) - 25.5, sd = sd_footlen)

#' We see that the power of the test = 0.072, hence P(type II Error) = 1 - 0.072 = 0.928, thus there is a 92.8% chance that the null hypothesis could be accept in case we draw multiple samples of size 20 from the population
#' 
#' We can further verify it by the following calculation in which we sample multiple 20 size sample from the population and calculate the fraction of cases in which null is accepted
#' 
## ------------------------------------------------------------------------

null_hypothesis_accepted = c()
set.seed(NULL)
for (i in 1:1000){
  temp = sample(foot_length$fl, 20)
  pval = t.test(temp, alternative = "two.sided", mu = 25.5)$p.value
  if (pval < 0.05 ){null_hypothesis_accepted = c(null_hypothesis_accepted, 0)}
  if (pval >= 0.05 ){null_hypothesis_accepted = c(null_hypothesis_accepted, 1)}
}
mean(null_hypothesis_accepted)

#'  In the above calculation we can see that although the null is false, in about 90% of the cases we see null being accepted
#'  
#' ## Part c
#' 
#' We need to test the hypothesis that
#' 
#' ##### H0 : $\mu_{Dancers} >= \mu_{Yoga}$
#' ##### H1 : $\mu_{Dancers} < \mu_{Yoga}$
#' 
## ----4c------------------------------------------------------------------
foot_length_full = read.csv("~/Downloads/1650715787495_footlength2.csv")
dancers = foot_length_full[foot_length_full$group == "Dancers", ]$fl
yoga = foot_length_full[foot_length_full$group == "Yoga", ]$fl

dancers_sample = sample(dancers, 20)
yoga_sample = sample(yoga, 20)

t.test(dancers_sample, yoga_sample, alternative = "l")

#' 
#' Since the p value > 0.05, we dont have enough evidence to conclude that Dancers have smaller feet than their yoga intructor counterparts
#' 
#' # Question 5
#' 
#' ## Part a
## ------------------------------------------------------------------------
bmi = read.table("~/Downloads/1650629459931_obesity.txt", header = TRUE, sep = "")
plot(x = bmi$BMI, y = bmi$Waist)

#' 
#' The relationship appears to be linear with a positive slope.
#' 
#' ## Part b
## ------------------------------------------------------------------------
model <- lm(BMI ~ Waist, data = bmi)
summary(model)

## ------------------------------------------------------------------------
plot(bmi$Waist,bmi$BMI)
abline(model,col=2)

#' 
#' 
## ------------------------------------------------------------------------
par(mfrow = c(2, 2))
plot(model)

#' 
#' 
#' 1. Since the residual vs fitted line is almost horizontal, thus the linearity assumption could be true
#' 2. We also see the Normal QQ plot along the line y = x, thus standardized residuals follow standard normal distribution. Thus residuals are normally distribution which is one of the assumption of linear regressions
#' 3. Since the scale location plot is not a horizontal line, there is some hetroscedascticity in the data. 
#' 
#' ## Part c
#' 
## ------------------------------------------------------------------------
newdata = data.frame(Waist=100)
predict(model, newdata, interval="confidence")


newdata = data.frame(Waist=150)
predict(model, newdata, interval="confidence")

#' 
#' Average BMI of adult with waist = 100 is 27.91 with confidence interval = (27.52301 28.30786)
#' 
#' Average BMI of adult with waist = 150 is 41.66 with confidence interval = (39.95883 43.37092)
#' 
#' 
#' ## Part d
## ------------------------------------------------------------------------
newdata = data.frame(Waist=100)
predict(model, newdata, interval="prediction")

#' 
#' BMI for waist 100  is 27.91 with prediction interval = (22.16542 33.66545)
#' 
#' ## Part e
#' 
#' BMI = 0.41656 +  0.27499* Waist
#' 
## ------------------------------------------------------------------------
(30 - 0.41656)/0.27499

#' 
#' Waist for BMI = 30 is 107.5801
